import wallme.websites.apod
import wallme.websites.astrobin
import wallme.websites.bing
import wallme.websites.epod
import wallme.websites.nasa
import wallme.websites.nationalgeographic
import wallme.websites.tetras
import wallme.websites.theguardian
import wallme.websites.thetelegraph
import wallme.websites.wikipedia
